#ifndef KNAVIGATIONBAR_H
#define KNAVIGATIONBAR_H

#include "gui_g.h"
#include <QScrollArea>
#include <QStandardItem>
#include <QModelIndex>
#include <QStandardItemModel>
#include <QListView>
#include <QMouseEvent>

namespace kdk
{

/** @defgroup BarModule
  * @{
  */

class KNavigationBarPrivate;
class ListView;

/**
 * @brief 导航栏控件
 */
class GUI_EXPORT KNavigationBar:public QScrollArea
{
    Q_OBJECT


public:

    enum NavigationBarDataType
    {
        ValueRole = Qt::UserRole + 1,
        StringRole = Qt::UserRole + 2,
        boolRole = Qt::UserRole + 3
    };


    KNavigationBar(QWidget*parent);

    /**
     * @brief 增加常规Item
     * @param item
     */
    void addItem(QStandardItem*item);

    /**
     * @brief 增加次级Item
     * @param subItem
     */
    void addSubItem(QStandardItem*subItem);

    /**
     * @brief 成组增加Item,在导航栏中会显示tag
     * @param items
     * @param tag
     */
    void addGroupItems(QList<QStandardItem*>items,const QString& tag);

    void insertGroupItems(QString tag ,int row,QStandardItem* item);

    void removeGroupItem(QString tag,QStandardItem* item);
    /**
     * @brief 添加tag
     * @param tag
     */
    void addTag(const QString& tag);

    /**
     * @brief 获取model
     * @return
     */
    QStandardItemModel* model();

    /**
     * @brief 获取view
     * @return
     */
    QListView* listview();


    /**
     * @brief 设置tabvalue
     * @param item
     * @param value
     * @since 2.5.1.2-0k1.0
     */
    void setTabValue(QStandardItem* item,QString value);//item

    /**
     * @brief 设置tabvalue是否可见
     * @param visible
     * @since 2.5.1.2-0k1.0
     */
    void setTabValueVisible(bool visible);

    /**
     * @brief tag 添加add图标
     * @param tag
     * @param icon
     * @since 2.5.1.2-0k1.0
     */
    void setAddIcon(QString tag,QIcon icon);

    /**
     * @brief 设置tag add图标是否可见
     * @param tag
     * @param visible
     * @since 2.5.1.2-0k1.0
     */
    void setAddTagVisible(QString tag,bool visible);

    /**
     * @brief 设置折叠图标是否可见
     * @param tag
     * @param visible
     * @since 2.5.1.2-0k1.0
     */
    void setExtendTagVisible(QString tag, bool visible);

Q_SIGNALS:
    void addTagClicked(QString str);

private:
    Q_DECLARE_PRIVATE(KNavigationBar)
    KNavigationBarPrivate*const d_ptr;
};

}
/**
  * @example testnavigationbar/widget.h
  * @example testnavigationbar/widget.cpp
  * @}
  */
#endif // KNAVIGATIONBAR_H
